# OctoBot-Launcher
[![PyPI](https://img.shields.io/pypi/v/OctoBot-Launcher.svg)](https://pypi.python.org/pypi/OctoBot-Launcher/)
[![Release](https://img.shields.io/github/downloads/Drakkar-Software/OctoBot-Launcher/total.svg)](https://github.com/Drakkar-Software/OctoBot-Launcher/releases)
[![Build Status](https://api.travis-ci.org/Drakkar-Software/OctoBot-Launcher.svg?branch=master)](https://travis-ci.org/Drakkar-Software/OctoBot-Launcher) 
[![Build status](https://ci.appveyor.com/api/projects/status/bcb75xy9dch6c3nx?svg=true)](https://ci.appveyor.com/project/Herklos/octobot-Launcher)


A launcher for your [OctoBot](https://github.com/Drakkar-Software/OctoBot) ! 

## Install
With [Python 3.7](https://www.python.org/downloads/) : 
``` {.sourceCode .bash}
$ pip3 install OctoBot-Launcher
```

## Usage
Start OctoBot launcher with : 
``` {.sourceCode .bash}
$ octobot-launcher
```
